==> cdk-soca-0.2.5.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.5](https://github.com/pahud/cdk-soca/compare/v0.2.4...v0.2.5) (2021-02-23)

### [0.2.4](https://github.com/pahud/cdk-soca/compare/v0.2.3...v0.2.4) (2021-02-21)

### [0.2.3](https://github.com/pahud/cdk-soca/compare/v0.2.2...v0.2.3) (2021-02-20)

### [0.2.2](https://github.com/pahud/cdk-soca/compare/v0.2.1...v0.2.2) (2021-02-19)

### [0.2.1](https://github.com/pahud/cdk-soca/compare/v0.2.0...v0.2.1) (2021-02-18)

### [0.1.136](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.1.136) (2021-02-18)


### Bug Fixes

* unable to create ES domain ([#163](https://github.com/pahud/cdk-soca/issues/163)) ([15fa9fd](https://github.com/pahud/cdk-soca/commit/15fa9fd51cb50411fd8eb98b1da3895cbbb5001e)), closes [#162](https://github.com/pahud/cdk-soca/issues/162) [#161](https://github.com/pahud/cdk-soca/issues/161)

## [0.2.0](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.2.0) (2021-02-18)


### Features

* scope down the ES security group and subnets ([a97ed96](https://github.com/pahud/cdk-soca/commit/a97ed96cb9e8878ac0c61cd121c5275d00ead2e9))
### [0.1.136](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.1.136) (2021-02-18)


### Bug Fixes

* unable to create ES domain ([8c5fbc2](https://github.com/pahud/cdk-soca/commit/8c5fbc227a50f848c830e163d018de877774c4cd))
* unable to create ES domain ([#163](https://github.com/pahud/cdk-soca/issues/163)) ([15fa9fd](https://github.com/pahud/cdk-soca/commit/15fa9fd51cb50411fd8eb98b1da3895cbbb5001e)), closes [#162](https://github.com/pahud/cdk-soca/issues/162) [#161](https://github.com/pahud/cdk-soca/issues/161)

### [0.1.135](https://github.com/pahud/cdk-soca/compare/v0.1.134...v0.1.135) (2021-02-18)

### [0.1.134](https://github.com/pahud/cdk-soca/compare/v0.1.133...v0.1.134) (2021-02-18)


### Features

* scope down the ES security group and subnets ([#159](https://github.com/pahud/cdk-soca/issues/159)) ([7290abe](https://github.com/pahud/cdk-soca/commit/7290abe54101d10e3cae2cab58d1ff8d37c19688))

### [0.1.133](https://github.com/pahud/cdk-soca/compare/v0.1.132...v0.1.133) (2021-02-18)


### Bug Fixes

* scope down the ES principals ([4a308c9](https://github.com/pahud/cdk-soca/commit/4a308c9b821903f3378c0b5c5dfecdc5808bfc06))

### [0.1.132](https://github.com/pahud/cdk-soca/compare/v0.1.131...v0.1.132) (2021-02-18)

### [0.1.131](https://github.com/pahud/cdk-soca/compare/v0.1.130...v0.1.131) (2021-02-17)

### [0.1.130](https://github.com/pahud/cdk-soca/compare/v0.1.129...v0.1.130) (2021-02-16)

### [0.1.129](https://github.com/pahud/cdk-soca/compare/v0.1.128...v0.1.129) (2021-02-15)

### [0.1.128](https://github.com/pahud/cdk-soca/compare/v0.1.127...v0.1.128) (2021-02-14)

### [0.1.127](https://github.com/pahud/cdk-soca/compare/v0.1.126...v0.1.127) (2021-02-13)

### [0.1.126](https://github.com/pahud/cdk-soca/compare/v0.1.125...v0.1.126) (2021-02-12)

### [0.1.125](https://github.com/pahud/cdk-soca/compare/v0.1.124...v0.1.125) (2021-02-11)

### [0.1.124](https://github.com/pahud/cdk-soca/compare/v0.1.123...v0.1.124) (2021-02-10)

### [0.1.123](https://github.com/pahud/cdk-soca/compare/v0.1.122...v0.1.123) (2021-02-09)

### [0.1.122](https://github.com/pahud/cdk-soca/compare/v0.1.121...v0.1.122) (2021-02-08)

### [0.1.121](https://github.com/pahud/cdk-soca/compare/v0.1.120...v0.1.121) (2021-02-07)


### Bug Fixes

* defaultReleaseBranch ([d9d2431](https://github.com/pahud/cdk-soca/commit/d9d2431e134f039686de0055995a2b23ec8a2b26))

### [0.1.120](https://github.com/pahud/cdk-soca/compare/v0.1.119...v0.1.120) (2021-02-07)

### [0.1.119](https://github.com/pahud/cdk-soca/compare/v0.1.118...v0.1.119) (2021-02-03)

### [0.1.118](https://github.com/pahud/cdk-soca/compare/v0.1.117...v0.1.118) (2021-02-02)

### [0.1.117](https://github.com/pahud/cdk-soca/compare/v0.1.116...v0.1.117) (2021-02-01)

### [0.1.116](https://github.com/pahud/cdk-soca/compare/v0.1.115...v0.1.116) (2021-01-30)

### [0.1.115](https://github.com/pahud/cdk-soca/compare/v0.1.114...v0.1.115) (2021-01-29)

### [0.1.114](https://github.com/pahud/cdk-soca/compare/v0.1.113...v0.1.114) (2021-01-28)

### [0.1.113](https://github.com/pahud/cdk-soca/compare/v0.1.112...v0.1.113) (2021-01-12)

### [0.1.112](https://github.com/pahud/cdk-soca/compare/v0.1.111...v0.1.112) (2021-01-11)

### [0.1.111](https://github.com/pahud/cdk-soca/compare/v0.1.110...v0.1.111) (2021-01-10)

### [0.1.110](https://github.com/pahud/cdk-soca/compare/v0.1.109...v0.1.110) (2021-01-09)

### [0.1.109](https://github.com/pahud/cdk-soca/compare/v0.1.108...v0.1.109) (2021-01-08)

### [0.1.108](https://github.com/pahud/cdk-soca/compare/v0.1.107...v0.1.108) (2021-01-07)

### [0.1.107](https://github.com/pahud/cdk-soca/compare/v0.1.106...v0.1.107) (2021-01-06)

### [0.1.106](https://github.com/pahud/cdk-soca/compare/v0.1.105...v0.1.106) (2021-01-05)

### [0.1.105](https://github.com/pahud/cdk-soca/compare/v0.1.104...v0.1.105) (2021-01-04)

### [0.1.104](https://github.com/pahud/cdk-soca/compare/v0.1.103...v0.1.104) (2021-01-03)

### [0.1.103](https://github.com/pahud/cdk-soca/compare/v0.1.102...v0.1.103) (2021-01-02)

### [0.1.102](https://github.com/pahud/cdk-soca/compare/v0.1.101...v0.1.102) (2021-01-01)

### [0.1.101](https://github.com/pahud/cdk-soca/compare/v0.1.100...v0.1.101) (2020-12-31)

### [0.1.100](https://github.com/pahud/cdk-soca/compare/v0.1.99...v0.1.100) (2020-12-30)

### [0.1.99](https://github.com/pahud/cdk-soca/compare/v0.1.98...v0.1.99) (2020-12-29)

### [0.1.98](https://github.com/pahud/cdk-soca/compare/v0.1.97...v0.1.98) (2020-12-28)

### [0.1.97](https://github.com/pahud/cdk-soca/compare/v0.1.96...v0.1.97) (2020-12-27)

### [0.1.96](https://github.com/pahud/cdk-soca/compare/v0.1.95...v0.1.96) (2020-12-26)

### 0.1.95 (2020-12-21)

### 0.1.94 (2020-12-20)

### 0.1.93 (2020-12-19)

### 0.1.92 (2020-12-13)

### 0.1.91 (2020-11-24)

### 0.1.90 (2020-11-23)

### 0.1.89 (2020-11-21)

### 0.1.88 (2020-11-20)

### 0.1.87 (2020-11-19)

### 0.1.86 (2020-11-18)

### 0.1.85 (2020-11-17)

### 0.1.84 (2020-11-16)

### 0.1.83 (2020-11-15)

### 0.1.82 (2020-11-14)

### 0.1.81 (2020-11-13)

### 0.1.80 (2020-11-12)

### 0.1.79 (2020-11-11)

### 0.1.78 (2020-11-10)

### 0.1.77 (2020-11-09)

### 0.1.76 (2020-11-08)

### 0.1.75 (2020-11-07)

### 0.1.74 (2020-11-06)

### 0.1.73 (2020-11-05)

### 0.1.72 (2020-11-04)

### 0.1.71 (2020-11-03)

### 0.1.70 (2020-11-02)

### 0.1.69 (2020-11-01)

### 0.1.68 (2020-10-31)

### 0.1.67 (2020-10-30)

### 0.1.66 (2020-10-29)

### 0.1.65 (2020-10-29)

### 0.1.64 (2020-10-28)

### 0.1.63 (2020-10-27)

### 0.1.62 (2020-10-26)

### 0.1.61 (2020-10-25)

### 0.1.60 (2020-10-24)

### 0.1.59 (2020-10-23)

### 0.1.58 (2020-10-22)

### 0.1.57 (2020-10-21)

### 0.1.56 (2020-10-20)


### Features

* **dev:** add gitpod support ([24a694d](https://github.com/pahud/cdk-soca/commit/24a694def528279d60ee67b2cf1ba2316c8346d1))

### 0.1.55 (2020-10-19)

### 0.1.54 (2020-10-19)

### 0.1.53 (2020-10-19)

### 0.1.52 (2020-10-18)

### 0.1.51 (2020-10-17)

### 0.1.50 (2020-10-16)

### 0.1.49 (2020-10-15)

### 0.1.48 (2020-10-15)

### 0.1.47 (2020-10-14)

### 0.1.46 (2020-10-13)

### 0.1.45 (2020-10-13)

### 0.1.44 (2020-10-13)

### 0.1.43 (2020-10-12)

### 0.1.42 (2020-10-12)

### 0.1.41 (2020-10-11)

### 0.1.40 (2020-10-10)

### 0.1.39 (2020-10-09)

### 0.1.38 (2020-10-08)

### 0.1.37 (2020-10-07)

### 0.1.36 (2020-10-07)

### 0.1.35 (2020-10-07)

### 0.1.34 (2020-10-06)

### 0.1.33 (2020-10-06)

### 0.1.32 (2020-10-06)

### 0.1.31 (2020-10-05)

### 0.1.30 (2020-10-05)

### 0.1.29 (2020-10-04)

### 0.1.28 (2020-10-04)

### 0.1.27 (2020-10-04)

### 0.1.26 (2020-10-03)

### 0.1.25 (2020-10-03)

### 0.1.24 (2020-10-02)

### 0.1.23 (2020-09-30)

### 0.1.22 (2020-09-30)

### 0.1.21 (2020-09-29)

### 0.1.20 (2020-09-29)

### 0.1.19 (2020-09-29)

### 0.1.18 (2020-09-29)


### Features

* **mergify:** allow mergify to auto-merge projen upgrade PRs once build passes ([5a3d84b](https://github.com/pahud/cdk-soca/commit/5a3d84ba653578b69b74d0758863fc5083c6f4bc))

### 0.1.17 (2020-09-29)

### 0.1.16 (2020-09-29)

### 0.1.15 (2020-09-29)

### 0.1.14 (2020-09-29)

### 0.1.13 (2020-09-29)

### 0.1.12 (2020-09-29)

### 0.1.11 (2020-09-28)

### 0.1.10 (2020-09-25)

### 0.1.9 (2020-09-25)

### 0.1.8 (2020-09-23)

### 0.1.7 (2020-09-22)

### 0.1.6 (2020-09-22)

### 0.1.5 (2020-09-21)

### 0.1.4 (2020-09-21)

### 0.1.3 (2020-09-21)

### 0.1.2 (2020-09-21)

### 0.1.1 (2020-09-21)

## 0.1.0 (2020-09-21)

==> cdk-soca-0.2.85.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.36](https://github.com/pahud/cdk-soca/compare/v0.2.35...v0.2.36) (2021-04-21)

### [0.2.35](https://github.com/pahud/cdk-soca/compare/v0.2.34...v0.2.35) (2021-04-20)

### [0.2.34](https://github.com/pahud/cdk-soca/compare/v0.2.33...v0.2.34) (2021-04-19)

### [0.2.33](https://github.com/pahud/cdk-soca/compare/v0.2.32...v0.2.33) (2021-04-18)

### [0.2.32](https://github.com/pahud/cdk-soca/compare/v0.2.31...v0.2.32) (2021-04-17)

### [0.2.31](https://github.com/pahud/cdk-soca/compare/v0.2.30...v0.2.31) (2021-04-16)

### [0.2.30](https://github.com/pahud/cdk-soca/compare/v0.2.29...v0.2.30) (2021-04-15)

### [0.2.29](https://github.com/pahud/cdk-soca/compare/v0.2.28...v0.2.29) (2021-04-14)

### [0.2.28](https://github.com/pahud/cdk-soca/compare/v0.2.27...v0.2.28) (2021-04-13)

### [0.2.27](https://github.com/pahud/cdk-soca/compare/v0.2.26...v0.2.27) (2021-04-12)

### [0.2.26](https://github.com/pahud/cdk-soca/compare/v0.2.25...v0.2.26) (2021-04-11)

### [0.2.25](https://github.com/pahud/cdk-soca/compare/v0.2.24...v0.2.25) (2021-04-10)

### [0.2.24](https://github.com/pahud/cdk-soca/compare/v0.2.23...v0.2.24) (2021-04-09)

### [0.2.23](https://github.com/pahud/cdk-soca/compare/v0.2.22...v0.2.23) (2021-04-08)

### [0.2.22](https://github.com/pahud/cdk-soca/compare/v0.2.21...v0.2.22) (2021-04-07)

### [0.2.21](https://github.com/pahud/cdk-soca/compare/v0.2.20...v0.2.21) (2021-04-05)

### [0.2.20](https://github.com/pahud/cdk-soca/compare/v0.2.19...v0.2.20) (2021-04-04)

### [0.2.19](https://github.com/pahud/cdk-soca/compare/v0.2.18...v0.2.19) (2021-04-03)

### [0.2.18](https://github.com/pahud/cdk-soca/compare/v0.2.17...v0.2.18) (2021-04-01)

### [0.2.17](https://github.com/pahud/cdk-soca/compare/v0.2.16...v0.2.17) (2021-03-18)

### [0.2.16](https://github.com/pahud/cdk-soca/compare/v0.2.15...v0.2.16) (2021-03-06)

### [0.2.15](https://github.com/pahud/cdk-soca/compare/v0.2.14...v0.2.15) (2021-03-05)

### [0.2.14](https://github.com/pahud/cdk-soca/compare/v0.2.13...v0.2.14) (2021-03-04)

### [0.2.13](https://github.com/pahud/cdk-soca/compare/v0.2.12...v0.2.13) (2021-03-03)

### [0.2.12](https://github.com/pahud/cdk-soca/compare/v0.2.11...v0.2.12) (2021-03-02)

### [0.2.11](https://github.com/pahud/cdk-soca/compare/v0.2.10...v0.2.11) (2021-03-01)

### [0.2.10](https://github.com/pahud/cdk-soca/compare/v0.2.9...v0.2.10) (2021-02-28)

### [0.2.9](https://github.com/pahud/cdk-soca/compare/v0.2.8...v0.2.9) (2021-02-27)

### [0.2.8](https://github.com/pahud/cdk-soca/compare/v0.2.7...v0.2.8) (2021-02-26)

### [0.2.7](https://github.com/pahud/cdk-soca/compare/v0.2.6...v0.2.7) (2021-02-25)

### [0.2.6](https://github.com/pahud/cdk-soca/compare/v0.2.5...v0.2.6) (2021-02-25)

### [0.2.5](https://github.com/pahud/cdk-soca/compare/v0.2.4...v0.2.5) (2021-02-23)

### [0.2.4](https://github.com/pahud/cdk-soca/compare/v0.2.3...v0.2.4) (2021-02-21)

### [0.2.3](https://github.com/pahud/cdk-soca/compare/v0.2.2...v0.2.3) (2021-02-20)

### [0.2.2](https://github.com/pahud/cdk-soca/compare/v0.2.1...v0.2.2) (2021-02-19)

### [0.2.1](https://github.com/pahud/cdk-soca/compare/v0.2.0...v0.2.1) (2021-02-18)

### [0.1.136](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.1.136) (2021-02-18)


### Bug Fixes

* unable to create ES domain ([#163](https://github.com/pahud/cdk-soca/issues/163)) ([15fa9fd](https://github.com/pahud/cdk-soca/commit/15fa9fd51cb50411fd8eb98b1da3895cbbb5001e)), closes [#162](https://github.com/pahud/cdk-soca/issues/162) [#161](https://github.com/pahud/cdk-soca/issues/161)

## [0.2.0](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.2.0) (2021-02-18)


### Features

* scope down the ES security group and subnets ([a97ed96](https://github.com/pahud/cdk-soca/commit/a97ed96cb9e8878ac0c61cd121c5275d00ead2e9))
### [0.1.136](https://github.com/pahud/cdk-soca/compare/v0.1.135...v0.1.136) (2021-02-18)


### Bug Fixes

* unable to create ES domain ([8c5fbc2](https://github.com/pahud/cdk-soca/commit/8c5fbc227a50f848c830e163d018de877774c4cd))
* unable to create ES domain ([#163](https://github.com/pahud/cdk-soca/issues/163)) ([15fa9fd](https://github.com/pahud/cdk-soca/commit/15fa9fd51cb50411fd8eb98b1da3895cbbb5001e)), closes [#162](https://github.com/pahud/cdk-soca/issues/162) [#161](https://github.com/pahud/cdk-soca/issues/161)

### [0.1.135](https://github.com/pahud/cdk-soca/compare/v0.1.134...v0.1.135) (2021-02-18)

### [0.1.134](https://github.com/pahud/cdk-soca/compare/v0.1.133...v0.1.134) (2021-02-18)


### Features

* scope down the ES security group and subnets ([#159](https://github.com/pahud/cdk-soca/issues/159)) ([7290abe](https://github.com/pahud/cdk-soca/commit/7290abe54101d10e3cae2cab58d1ff8d37c19688))

### [0.1.133](https://github.com/pahud/cdk-soca/compare/v0.1.132...v0.1.133) (2021-02-18)


### Bug Fixes

* scope down the ES principals ([4a308c9](https://github.com/pahud/cdk-soca/commit/4a308c9b821903f3378c0b5c5dfecdc5808bfc06))

### [0.1.132](https://github.com/pahud/cdk-soca/compare/v0.1.131...v0.1.132) (2021-02-18)

### [0.1.131](https://github.com/pahud/cdk-soca/compare/v0.1.130...v0.1.131) (2021-02-17)

### [0.1.130](https://github.com/pahud/cdk-soca/compare/v0.1.129...v0.1.130) (2021-02-16)

### [0.1.129](https://github.com/pahud/cdk-soca/compare/v0.1.128...v0.1.129) (2021-02-15)

### [0.1.128](https://github.com/pahud/cdk-soca/compare/v0.1.127...v0.1.128) (2021-02-14)

### [0.1.127](https://github.com/pahud/cdk-soca/compare/v0.1.126...v0.1.127) (2021-02-13)

### [0.1.126](https://github.com/pahud/cdk-soca/compare/v0.1.125...v0.1.126) (2021-02-12)

### [0.1.125](https://github.com/pahud/cdk-soca/compare/v0.1.124...v0.1.125) (2021-02-11)

### [0.1.124](https://github.com/pahud/cdk-soca/compare/v0.1.123...v0.1.124) (2021-02-10)

### [0.1.123](https://github.com/pahud/cdk-soca/compare/v0.1.122...v0.1.123) (2021-02-09)

### [0.1.122](https://github.com/pahud/cdk-soca/compare/v0.1.121...v0.1.122) (2021-02-08)

### [0.1.121](https://github.com/pahud/cdk-soca/compare/v0.1.120...v0.1.121) (2021-02-07)


### Bug Fixes

* defaultReleaseBranch ([d9d2431](https://github.com/pahud/cdk-soca/commit/d9d2431e134f039686de0055995a2b23ec8a2b26))

### [0.1.120](https://github.com/pahud/cdk-soca/compare/v0.1.119...v0.1.120) (2021-02-07)

### [0.1.119](https://github.com/pahud/cdk-soca/compare/v0.1.118...v0.1.119) (2021-02-03)

### [0.1.118](https://github.com/pahud/cdk-soca/compare/v0.1.117...v0.1.118) (2021-02-02)

### [0.1.117](https://github.com/pahud/cdk-soca/compare/v0.1.116...v0.1.117) (2021-02-01)

### [0.1.116](https://github.com/pahud/cdk-soca/compare/v0.1.115...v0.1.116) (2021-01-30)

### [0.1.115](https://github.com/pahud/cdk-soca/compare/v0.1.114...v0.1.115) (2021-01-29)

### [0.1.114](https://github.com/pahud/cdk-soca/compare/v0.1.113...v0.1.114) (2021-01-28)

### [0.1.113](https://github.com/pahud/cdk-soca/compare/v0.1.112...v0.1.113) (2021-01-12)

### [0.1.112](https://github.com/pahud/cdk-soca/compare/v0.1.111...v0.1.112) (2021-01-11)

### [0.1.111](https://github.com/pahud/cdk-soca/compare/v0.1.110...v0.1.111) (2021-01-10)

### [0.1.110](https://github.com/pahud/cdk-soca/compare/v0.1.109...v0.1.110) (2021-01-09)

### [0.1.109](https://github.com/pahud/cdk-soca/compare/v0.1.108...v0.1.109) (2021-01-08)

### [0.1.108](https://github.com/pahud/cdk-soca/compare/v0.1.107...v0.1.108) (2021-01-07)

### [0.1.107](https://github.com/pahud/cdk-soca/compare/v0.1.106...v0.1.107) (2021-01-06)

### [0.1.106](https://github.com/pahud/cdk-soca/compare/v0.1.105...v0.1.106) (2021-01-05)

### [0.1.105](https://github.com/pahud/cdk-soca/compare/v0.1.104...v0.1.105) (2021-01-04)

### [0.1.104](https://github.com/pahud/cdk-soca/compare/v0.1.103...v0.1.104) (2021-01-03)

### [0.1.103](https://github.com/pahud/cdk-soca/compare/v0.1.102...v0.1.103) (2021-01-02)

### [0.1.102](https://github.com/pahud/cdk-soca/compare/v0.1.101...v0.1.102) (2021-01-01)

### [0.1.101](https://github.com/pahud/cdk-soca/compare/v0.1.100...v0.1.101) (2020-12-31)

### [0.1.100](https://github.com/pahud/cdk-soca/compare/v0.1.99...v0.1.100) (2020-12-30)

### [0.1.99](https://github.com/pahud/cdk-soca/compare/v0.1.98...v0.1.99) (2020-12-29)

### [0.1.98](https://github.com/pahud/cdk-soca/compare/v0.1.97...v0.1.98) (2020-12-28)

### [0.1.97](https://github.com/pahud/cdk-soca/compare/v0.1.96...v0.1.97) (2020-12-27)

### [0.1.96](https://github.com/pahud/cdk-soca/compare/v0.1.95...v0.1.96) (2020-12-26)

### 0.1.95 (2020-12-21)

### 0.1.94 (2020-12-20)

### 0.1.93 (2020-12-19)

### 0.1.92 (2020-12-13)

### 0.1.91 (2020-11-24)

### 0.1.90 (2020-11-23)

### 0.1.89 (2020-11-21)

### 0.1.88 (2020-11-20)

### 0.1.87 (2020-11-19)

### 0.1.86 (2020-11-18)

### 0.1.85 (2020-11-17)

### 0.1.84 (2020-11-16)

### 0.1.83 (2020-11-15)

### 0.1.82 (2020-11-14)

### 0.1.81 (2020-11-13)

### 0.1.80 (2020-11-12)

### 0.1.79 (2020-11-11)

### 0.1.78 (2020-11-10)

### 0.1.77 (2020-11-09)

### 0.1.76 (2020-11-08)

### 0.1.75 (2020-11-07)

### 0.1.74 (2020-11-06)

### 0.1.73 (2020-11-05)

### 0.1.72 (2020-11-04)

### 0.1.71 (2020-11-03)

### 0.1.70 (2020-11-02)

### 0.1.69 (2020-11-01)

### 0.1.68 (2020-10-31)

### 0.1.67 (2020-10-30)

### 0.1.66 (2020-10-29)

### 0.1.65 (2020-10-29)

### 0.1.64 (2020-10-28)

### 0.1.63 (2020-10-27)

### 0.1.62 (2020-10-26)

### 0.1.61 (2020-10-25)

### 0.1.60 (2020-10-24)

### 0.1.59 (2020-10-23)

### 0.1.58 (2020-10-22)

### 0.1.57 (2020-10-21)

### 0.1.56 (2020-10-20)


### Features

* **dev:** add gitpod support ([24a694d](https://github.com/pahud/cdk-soca/commit/24a694def528279d60ee67b2cf1ba2316c8346d1))

### 0.1.55 (2020-10-19)

### 0.1.54 (2020-10-19)

### 0.1.53 (2020-10-19)

### 0.1.52 (2020-10-18)

### 0.1.51 (2020-10-17)

### 0.1.50 (2020-10-16)

### 0.1.49 (2020-10-15)

### 0.1.48 (2020-10-15)

### 0.1.47 (2020-10-14)

### 0.1.46 (2020-10-13)

### 0.1.45 (2020-10-13)

### 0.1.44 (2020-10-13)

### 0.1.43 (2020-10-12)

### 0.1.42 (2020-10-12)

### 0.1.41 (2020-10-11)

### 0.1.40 (2020-10-10)

### 0.1.39 (2020-10-09)

### 0.1.38 (2020-10-08)

### 0.1.37 (2020-10-07)

### 0.1.36 (2020-10-07)

### 0.1.35 (2020-10-07)

### 0.1.34 (2020-10-06)

### 0.1.33 (2020-10-06)

### 0.1.32 (2020-10-06)

### 0.1.31 (2020-10-05)

### 0.1.30 (2020-10-05)

### 0.1.29 (2020-10-04)

### 0.1.28 (2020-10-04)

### 0.1.27 (2020-10-04)

### 0.1.26 (2020-10-03)

### 0.1.25 (2020-10-03)

### 0.1.24 (2020-10-02)

### 0.1.23 (2020-09-30)

### 0.1.22 (2020-09-30)

### 0.1.21 (2020-09-29)

### 0.1.20 (2020-09-29)

### 0.1.19 (2020-09-29)

### 0.1.18 (2020-09-29)


### Features

* **mergify:** allow mergify to auto-merge projen upgrade PRs once build passes ([5a3d84b](https://github.com/pahud/cdk-soca/commit/5a3d84ba653578b69b74d0758863fc5083c6f4bc))

### 0.1.17 (2020-09-29)

### 0.1.16 (2020-09-29)

### 0.1.15 (2020-09-29)

### 0.1.14 (2020-09-29)

### 0.1.13 (2020-09-29)

### 0.1.12 (2020-09-29)

### 0.1.11 (2020-09-28)

### 0.1.10 (2020-09-25)

### 0.1.9 (2020-09-25)

### 0.1.8 (2020-09-23)

### 0.1.7 (2020-09-22)

### 0.1.6 (2020-09-22)

### 0.1.5 (2020-09-21)

### 0.1.4 (2020-09-21)

### 0.1.3 (2020-09-21)

### 0.1.2 (2020-09-21)

### 0.1.1 (2020-09-21)

## 0.1.0 (2020-09-21)
